==> stagexl-0.12.0.tar.gz: README.md <==
# StageXL 

StageXL is a fast and universal 2D rendering engine for HTML5 and Dart. 
It provides a wide range of features for 2D games and other graphically 
rich content. The WebGL based engine is highly optimized to reduce the
number of draw calls sent to the GPU and therefore delivers top-class
performance. The automatic fallback to a Canvas2D based engine guarantees 
compatibility with older browsers or legacy hardware. 

Some of the features provided by StageXL are: texture atlas support, 
draw call batching, pixel masking, pixel filters, pixel blending,
texture filtering, hierarchical display list, sprite sheet animations, 
rich animation framework, audio and video support, interaction events,
3D transformations of 2D objects, resource management, text rendering 
and many other features as well as extensibility for even more features.

[![Build Status](https://drone.io/github.com/bp74/StageXL/status.png)](https://drone.io/github.com/bp74/StageXL/latest)

## Extension Libraries

StageXL provides a rich set of built-in features. Even more advanced use cases 
may require an extension library with a specialised set of features. The number
of extension libraries is growing over time, here is a list of the most popular
StageXL extension libraries.   

* Bitmap Fonts: <https://github.com/bp74/StageXL_BitmapFont>
* Spine Runtime: <https://github.com/bp74/StageXL_Spine>
* Flump Runtime: <https://github.com/bp74/StageXL_Flump>
* Particle Emitter: <https://github.com/bp74/StageXL_Particle>
* Rich Text Field: <https://github.com/realbluesky/StageXL_RichTextField>

## Getting Help

The easiest way to get started or to accomplish a task is to ask questions.
We are actively tracking the following websites and answer questions as fast
as possible. We would like to get more FAQs on StackOverflow to help other
developers to find answers quickly, therefore it would be great to get your
questions on StackOverflow.

* StageXL Forum: <https://groups.google.com/forum/#!forum/stagexl>
* StageXL GitHub Issues: <https://github.com/bp74/StageXL/issues>
* StageXL StackOverflow: <http://stackoverflow.com/questions/ask?tags=stagexl>
* StageXL API Reference: <http://www.stagexl.org/docs/api/index.html>

## Examples

We are working on more examples to covering a wider range of use cases. 
Please take a look at the StageXL samples repository for our ongoing work. 
Don't hesitate to send example requests that would help you to learn about 
a particular feature.

* GitHub repository: <https://github.com/bp74/StageXL_Samples>
* StageXL homepage: <http://www.stagexl.org/samples> 

## Roadmap

Besides improving our existing features and improving performance as much
as possible, we are always thinking about new features we want to add next.
Please send us your ideas and requests to make those things a reality you
care about most. Some of the things we will tackle in the near future are:

* Getting closer to version 1.0.
* Runtime support for GAF Converter.
* Runtime support for Tiled Map Editor.
* Support for Sky (native runtime environment for Android).
* A new StageXL homepage with more articles / blog posts.

## Adobe Flash heritage

StageXL started as an easy migration path for Adobe Flash developers and their
products to HTML5. Therefore StageXL provides the same display list API you
may have used in Flash for many years. Furthermore the Dart programming
language is easy to use for everyone who is familiar with ActionScript. 

* Toolkit for Dart: <http://toolkitfordart.github.io>
* ActionScript to Dart converter: <https://github.com/blockforest/stagexl-converter-pubrun>
* ActionScript to Dart comparison: <http://www.stagexl.org/docs/actionscript-dart.html>

==> stagexl-0.13.1.tar.gz: README.md <==
# StageXL 

StageXL is a fast and universal 2D rendering engine for HTML5 and Dart. 
It provides a wide range of features for 2D games and other graphically 
rich content. The WebGL based engine is highly optimized to reduce the
number of draw calls sent to the GPU and therefore delivers top-class
performance. The automatic fallback to a Canvas2D based engine guarantees 
compatibility with older browsers or legacy hardware. 

Some of the features provided by StageXL are: texture atlas support, 
draw call batching, pixel masking, pixel filters, pixel blending,
texture filtering, hierarchical display list, sprite sheet animations, 
rich animation framework, audio and video support, interaction events,
3D transformations of 2D objects, resource management, text rendering 
and many other features as well as extensibility for even more features.

[![Build Status](https://travis-ci.org/bp74/StageXL.svg?branch=master)](https://travis-ci.org/bp74/StageXL)

## Extension Libraries

StageXL provides a rich set of built-in features. Even more advanced use cases 
may require an extension library with a specialised set of features. The number
of extension libraries is growing over time, here is a list of the most popular
StageXL extension libraries.   

* Bitmap Fonts: <https://github.com/bp74/StageXL_BitmapFont>
* Spine Runtime: <https://github.com/bp74/StageXL_Spine>
* DragonBones Runtime: <https://github.com/bp74/StageXL_DragonBones>
* Flump Runtime: <https://github.com/bp74/StageXL_Flump>
* Particle Emitter: <https://github.com/bp74/StageXL_Particle>
* Rich Text Field: <https://github.com/realbluesky/StageXL_RichTextField>

## Getting Help

The easiest way to get started or to accomplish a task is to ask questions.
We are actively tracking the following websites and answer questions as fast
as possible. We would like to get more FAQs on StackOverflow to help other
developers to find answers quickly, therefore it would be great to get your
questions on StackOverflow.

* StageXL Forum: <https://groups.google.com/forum/#!forum/stagexl>
* StageXL GitHub Issues: <https://github.com/bp74/StageXL/issues>
* StageXL StackOverflow: <http://stackoverflow.com/questions/ask?tags=stagexl>
* StageXL API Reference: <http://www.stagexl.org/docs/api/index.html>

## Examples

We are working on more examples to covering a wider range of use cases. 
Please take a look at the StageXL samples repository for our ongoing work. 
Don't hesitate to send example requests that would help you to learn about 
a particular feature.

* GitHub repository: <https://github.com/bp74/StageXL_Samples>
* StageXL homepage: <http://www.stagexl.org/samples> 

## Roadmap

Besides improving our existing features and improving performance as much
as possible, we are always thinking about new features we want to add next.
Please send us your ideas and requests to make those things a reality you
care about most. Some of the things we will tackle in the near future are:

* Getting closer to version 1.0.
* Runtime support for GAF Converter.
* Runtime support for Tiled Map Editor.
* Support for Sky (native runtime environment for Android).
* A new StageXL homepage with more articles / blog posts.

## Adobe Flash heritage

StageXL started as an easy migration path for Adobe Flash developers and their
products to HTML5. Therefore StageXL provides the same display list API you
may have used in Flash for many years. Furthermore the Dart programming
language is easy to use for everyone who is familiar with ActionScript. 

* Toolkit for Dart: <http://toolkitfordart.github.io>
* ActionScript to Dart converter: <https://github.com/blockforest/stagexl-converter-pubrun>
* ActionScript to Dart comparison: <http://www.stagexl.org/docs/actionscript-dart.html>
